@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Nominum, Inc.
+# Copyright (C) 2003, 2004 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,7 +13,7 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: CERT.py,v 1.9 2003/06/30 06:08:27 halley Exp $
+# $Id: CERT.py,v 1.12 2004/03/19 00:17:27 halley Exp $
 
 import cStringIO
 import struct
@@ -63,6 +63,8 @@ class CERT(dns.rdata.Rdata):
     @ivar certificate: the certificate or CRL
     @type certificate: string
     @see: RFC 2538"""
+
+    __slots__ = ['certificate_type', 'key_tag', 'algorithm', 'certificate']
     
     def __init__(self, rdclass, rdtype, certificate_type, key_tag, algorithm,
                  certificate):
@@ -80,7 +82,7 @@ class CERT(dns.rdata.Rdata):
         
     def from_text(cls, rdclass, rdtype, tok, origin = None, relativize = True):
         certificate_type = _ctype_from_text(tok.get_string())
-        key_type = tok.get_uint16()
+        key_tag = tok.get_uint16()
         algorithm = dns.dnssec.algorithm_from_text(tok.get_string())
         if algorithm < 0 or algorithm > 255:
             raise dns.exception.SyntaxError, "bad algorithm type"
@@ -94,7 +96,7 @@ class CERT(dns.rdata.Rdata):
             chunks.append(t[1])
         b64 = ''.join(chunks)
         certificate = b64.decode('base64_codec')
-        return cls(rdclass, rdtype, certificate_type, key_type,
+        return cls(rdclass, rdtype, certificate_type, key_tag,
                    algorithm, certificate)
     
     from_text = classmethod(from_text)
