@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Nominum, Inc.
+# Copyright (C) 2003, 2004 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,7 +13,7 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: update.py,v 1.9 2003/06/24 02:37:00 halley Exp $
+# $Id: update.py,v 1.15 2004/03/19 00:17:27 halley Exp $
 
 """DNS Dynamic Update Support"""
 
@@ -54,21 +54,20 @@ class Update(dns.message.Message):
         if isinstance(rdclass, str):
             rdclass = dns.rdataclass.from_text(rdclass)
         self.zone_rdclass = rdclass
-        n = self.find_node(self.question, self.origin, True, True)
-        n.find_rdataset(rdclass, dns.rdatatype.SOA, dns.rdatatype.NONE, True)
+        self.find_rrset(self.question, self.origin, rdclass, dns.rdatatype.SOA,
+                        create=True, force_unique=True)
         if not keyring is None:
             self.use_tsig(keyring, keyname)
 
-    def _add_rr(self, name, ttl, rd, deleting=0, section=None):
+    def _add_rr(self, name, ttl, rd, deleting=None, section=None):
         """Add a single RR to the update section."""
 
         if section is None:
             section = self.authority
-        n = self.find_node(section, name, True, True)
         covers = rd.covers()
-        rds = n.find_rdataset(self.zone_rdclass, rd.rdtype, covers, True, True,
-                              deleting)
-        rds.add(rd, ttl)
+        rrset = self.find_rrset(section, name, self.zone_rdclass, rd.rdtype,
+                                covers, deleting, True, True)
+        rrset.add(rd, ttl)
 
     def _add(self, replace, section, name, *args):
         """Add records.  The first argument is the replace mode.  If
@@ -98,7 +97,7 @@ class Update(dns.message.Message):
                 if replace:
                     self.delete(name, args[0].rdtype)
                 for rd in args:
-                    self._add_rr(name, ttl, r, section=section)
+                    self._add_rr(name, ttl, rd, section=section)
             else:
                 rdtype = args.pop(0)
                 if isinstance(rdtype, str):
@@ -136,28 +135,28 @@ class Update(dns.message.Message):
         if isinstance(name, str):
             name = dns.name.from_text(name, None)
         if len(args) == 0:
-            n = self.find_node(self.authority, name, True, True)
-            rds = n.find_rdataset(dns.rdataclass.ANY, dns.rdatatype.ANY,
-                                  dns.rdatatype.NONE, True, True,
-                                  dns.rdatatype.ANY)
+            rrset = self.find_rrset(self.authority, name, dns.rdataclass.ANY,
+                                    dns.rdatatype.ANY, dns.rdatatype.NONE,
+                                    dns.rdatatype.ANY, True, True)
         elif isinstance(args[0], dns.rdataset.Rdataset):
             for rds in args:
                 for rd in rds:
-                    self._add_rr(name, 0, rd, dns.rdatatype.NONE)
+                    self._add_rr(name, 0, rd, dns.rdataclass.NONE)
         else:
             args = list(args)
             if isinstance(args[0], dns.rdata.Rdata):
                 for rd in args:
-                    self._add_rr(name, 0, rd, dns.rdatatype.NONE)
+                    self._add_rr(name, 0, rd, dns.rdataclass.NONE)
             else:
                 rdtype = args.pop(0)
                 if isinstance(rdtype, str):
                     rdtype = dns.rdatatype.from_text(rdtype)
                 if len(args) == 0:
-                    n = self.find_node(self.authority, name, True, True)
-                    rds = n.find_rdataset(self.zone_rdclass, rdtype,
-                                          dns.rdatatype.NONE, True, True,
-                                          dns.rdataclass.ANY)
+                    rrset = self.find_rrset(self.authority, name,
+                                            self.zone_rdclass, rdtype,
+                                            dns.rdatatype.NONE,
+                                            dns.rdataclass.ANY,
+                                            True, True)
                 else:
                     for s in args:
                         rd = dns.rdata.from_text(self.zone_rdclass, rdtype, s,
@@ -194,9 +193,10 @@ class Update(dns.message.Message):
         if isinstance(name, str):
             name = dns.name.from_text(name, None)
         if len(args) == 0:
-            n = self.find_node(self.answer, name, True, True)
-            rds = n.find_rdataset(dns.rdataclass.ANY, dns.rdatatype.ANY,
-                                  dns.rdatatype.NONE, True, True)
+            rrset = self.find_rrset(self.answer, name,
+                                    dns.rdataclass.ANY, dns.rdatatype.ANY,
+                                    dns.rdatatype.NONE, None,
+                                    True, True)
         elif isinstance(args[0], dns.rdataset.Rdataset) or \
              isinstance(args[0], dns.rdata.Rdata) or \
              len(args) > 1:
@@ -209,9 +209,10 @@ class Update(dns.message.Message):
             rdtype = args[0]
             if isinstance(rdtype, str):
                 rdtype = dns.rdatatype.from_text(rdtype)
-            n = self.find_node(self.answer, name, True, True)
-            rds = n.find_rdataset(dns.rdataclass.ANY, rdtype,
-                                  dns.rdatatype.NONE, True, True)
+            rrset = self.find_rrset(self.answer, name,
+                                    dns.rdataclass.ANY, rdtype,
+                                    dns.rdatatype.NONE, None,
+                                    True, True)
 
     def absent(self, name, rdtype=None):
         """Require that an owner name (and optionally an rdata type) does
@@ -219,20 +220,23 @@ class Update(dns.message.Message):
 
         if isinstance(name, str):
             name = dns.name.from_text(name, None)
-        n = self.find_node(self.answer, name, True, True)
         if rdtype is None:
-            rds = n.find_rdataset(dns.rdataclass.NONE, dns.rdatatype.ANY, 
-                                  dns.rdatatype.NONE, True, True)
+            rrset = self.find_rrset(self.answer, name,
+                                    dns.rdataclass.NONE, dns.rdatatype.ANY, 
+                                    dns.rdatatype.NONE, None,
+                                    True, True)
         else:
             if isinstance(rdtype, str):
                 rdtype = dns.rdatatype.from_text(rdtype)
-            rds = n.find_rdataset(dns.rdataclass.NONE, rdtype,
-                                  dns.rdatatype.NONE, True, True)
+            rrset = self.find_rrset(self.answer, name,
+                                    dns.rdataclass.NONE, rdtype,
+                                    dns.rdatatype.NONE, None,
+                                    True, True)
 
-    def to_wire(self, origin=None):
+    def to_wire(self, origin=None, max_size=65535):
         """Return a string containing the update in DNS compressed wire
         format.
         @rtype: string"""
         if origin is None:
             origin = self.origin
-        return super(Update, self).to_wire(origin)
+        return super(Update, self).to_wire(origin, max_size)
